@@ -32,6 +32,7 @@
 #include <Plasma/Applet>
 #include <Plasma/Containment>
 #include <Plasma/Corona>
+#include <qquickitem.h>
 
 namespace PlasmaQuick
 {
@@ -370,8 +371,10 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
             currentRepresentationItem = item;
             connectLayoutAttached(item);
 
-            expanded = true;
-            Q_EMIT q->expandedChanged(true);
+            if (!expanded) {
+                expanded = true;
+                Q_EMIT q->expandedChanged(true);
+            }
         }
 
     } else {
@@ -397,8 +400,10 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
             currentRepresentationItem = compactItem;
             connectLayoutAttached(compactItem);
 
-            expanded = false;
-            Q_EMIT q->expandedChanged(false);
+            if (expanded) {
+                expanded = false;
+                Q_EMIT q->expandedChanged(false);
+            }
         }
     }
 
@@ -623,9 +628,15 @@ AppletQuickItem *AppletQuickItem::itemForApplet(Plasma::Applet *applet)
         qmlObject->rootContext()->setContextProperty(QStringLiteral("plasmoid"), applet);
     }
 
-    applet->connect(applet, &Plasma::Applet::appletDeleted, applet, [](Plasma::Applet *applet) {
-        delete AppletQuickItemPrivate::s_itemsForApplet[applet];
-        AppletQuickItemPrivate::s_itemsForApplet.remove(applet);
+    QObject::connect(applet, &Plasma::Applet::appletDeleted, item, [qmlObject](Plasma::Applet *applet) {
+        // Deleting qmlObject will also delete the instantiated plasmoidItem
+        // deleteing just the plasmoiditem will cause a double deletion when qmlObject
+        // gets deleted by applet deletion
+        if (qmlObject->parent() == applet) {
+            // appletDelete can also be emitted by a containment for one of its children
+            delete qmlObject;
+            AppletQuickItemPrivate::s_itemsForApplet.remove(applet);
+        }
     });
 
     applet->setProperty("_plasmoid", QVariant::fromValue(item));
@@ -643,6 +654,9 @@ void AppletQuickItem::init()
         // This can happen only if the client QML code declares a PlasmoidItem somewhere else than the root object
         return;
     }
+    if (d->initComplete) {
+        return;
+    }
 
     if (d->applet->containment()) {
         if (d->applet->containment()->corona()) {
@@ -720,6 +734,12 @@ void AppletQuickItem::classBegin()
     d->qmlObject = ac->sharedQmlEngine();
 }
 
+void AppletQuickItem::componentComplete()
+{
+    QQuickItem::componentComplete();
+    init();
+}
+
 int AppletQuickItem::switchWidth() const
 {
     return d->switchWidth;
@@ -906,20 +926,6 @@ void AppletQuickItem::geometryChange(const QRectF &newGeometry, const QRectF &ol
     QQuickItem::geometryChange(newGeometry, oldGeometry);
     d->compactRepresentationCheck();
 }
-
-void AppletQuickItem::itemChange(ItemChange change, const ItemChangeData &value)
-{
-    if (change == QQuickItem::ItemSceneChange) {
-        // we have a window: create the representations if needed
-        // also avoid initializing the item more than once,
-        // since this will cause shortcut to open and close the item immediately
-        if (value.window && !d->initComplete) {
-            init();
-        }
-    }
-
-    QQuickItem::itemChange(change, value);
-}
 }
 
 #include "moc_appletquickitem.cpp"
