@@ -102,7 +102,6 @@ public:
     QPointer<QQuickItem> fullRepresentationItem;
     QPointer<QQuickItem> compactRepresentationExpanderItem;
     QPointer<QQuickItem> currentRepresentationItem;
-    QPointer<QObject> testItem;
 
     // Attached layout objects: own and the representation's one
     QPointer<QObject> representationLayout;
@@ -111,9 +110,7 @@ public:
     Plasma::Applet *applet = nullptr;
     PlasmaQuick::SharedQmlEngine *qmlObject;
 
-    KPackage::Package appletPackage;
     KPackage::Package coronaPackage;
-    KPackage::Package containmentPackage;
 
     bool expanded = false;
     bool hideOnWindowDeactivate = false;
